# Contributing

Issues and pull requests are most welcome.

To get started, fork this repository, clone it, and run `poetry install` to install it locally.

The project uses [lefthook](https://github.com/evilmartians/lefthook) for development-time tasks. You can see the up-to-date pre-push and pre-commit configurations in the [configuration](lefthook.yml).

To verify your changes work, run the unit tests with `lefthook run pre-push`.

Next, check the issues page or see if there's anything to improve in the existing codebase and start submitting your changes.
